@@ -9,33 +9,11 @@ from sklearn.metrics import precision_recall_curve as sklearn_precision_recall_c
 from sklearn.metrics import roc_curve as sklearn_roc_curve
 from sklearn.preprocessing import LabelBinarizer
 from sklearn.utils.multiclass import unique_labels
-from woodwork.logical_types import BooleanNullable, IntegerNullable
 
 from evalml.exceptions import NoPositiveLabelException
 from evalml.utils import import_or_raise, infer_feature_types, jupyter_check
 
 
-def _convert_ww_series_to_np_array(ww_series):
-    """Helper function to properly convert IntegerNullable/BooleanNullable Woodwork series to numpy arrays.
-
-    Args:
-        ww_series: Woodwork init-ed series possibly containing IntegerNullable or BooleanNullable datatype
-
-    Returns:
-        numpy.ndarray: The values of ww_series but in an array.
-    """
-    np_series = ww_series.to_numpy()
-    if isinstance(ww_series.ww.logical_type, BooleanNullable):
-        np_series = np_series.astype("bool")
-    if isinstance(ww_series.ww.logical_type, IntegerNullable):
-        try:
-            np_series = np_series.astype("int64")
-        except TypeError:
-            np_series = ww_series.astype(float).to_numpy()
-
-    return np_series
-
-
 def confusion_matrix(y_true, y_predicted, normalize_method="true"):
     """Confusion matrix for binary and multiclass classification.
 
@@ -48,11 +26,9 @@ def confusion_matrix(y_true, y_predicted, normalize_method="true"):
         pd.DataFrame: Confusion matrix. The column header represents the predicted labels while row header represents the actual labels.
     """
     y_true_ww = infer_feature_types(y_true)
-    y_true_np = _convert_ww_series_to_np_array(y_true_ww)
     y_predicted = infer_feature_types(y_predicted)
-    y_predicted = y_predicted.to_numpy()
-    labels = unique_labels(y_true_np, y_predicted)
-    conf_mat = sklearn_confusion_matrix(y_true_np, y_predicted)
+    labels = unique_labels(y_true_ww, y_predicted)
+    conf_mat = sklearn_confusion_matrix(y_true_ww, y_predicted)
     conf_mat = pd.DataFrame(conf_mat, index=labels, columns=labels)
     if normalize_method is not None:
         return normalize_confusion_matrix(conf_mat, normalize_method=normalize_method)
@@ -271,7 +247,7 @@ def roc_curve(y_true, y_pred_proba):
 
     Args:
         y_true (pd.Series or np.ndarray): True labels.
-        y_pred_proba (pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied.
+        y_pred_proba (pd.Series or pd.DataFrame or np.ndarray): Predictions from a classifier, before thresholding has been applied.
 
     Returns:
         list(dict): A list of dictionaries (with one for each class) is returned. Binary classification problems return a list with one dictionary.
@@ -282,27 +258,30 @@ def roc_curve(y_true, y_pred_proba):
                   * `auc_score`: The area under the ROC curve.
     """
     y_true_ww = infer_feature_types(y_true)
-    y_true_np = _convert_ww_series_to_np_array(y_true_ww)
-    y_pred_proba = infer_feature_types(y_pred_proba).to_numpy()
+    y_pred_proba = infer_feature_types(y_pred_proba)
 
-    if len(y_pred_proba.shape) == 1:
-        y_pred_proba = y_pred_proba.reshape(-1, 1)
-    if y_pred_proba.shape[1] == 2:
-        y_pred_proba = y_pred_proba[:, 1].reshape(-1, 1)
-    nan_indices = np.logical_or(pd.isna(y_true_np), np.isnan(y_pred_proba).any(axis=1))
-    y_true_np = y_true_np[~nan_indices]
+    # Standardize data to be a DataFrame even for binary target
+    if isinstance(y_pred_proba, pd.Series):
+        y_pred_proba = pd.DataFrame(y_pred_proba)
+    # Only use one column for binary inputs that are still a DataFrame
+    elif y_pred_proba.shape[1] == 2:
+        y_pred_proba = pd.DataFrame(y_pred_proba.iloc[:, 1])
+
+    nan_indices = np.logical_or(pd.isna(y_true_ww), pd.isna(y_pred_proba).any(axis=1))
+    y_true_ww = y_true_ww[~nan_indices]
     y_pred_proba = y_pred_proba[~nan_indices]
 
     lb = LabelBinarizer()
-    lb.fit(np.unique(y_true_np))
-    y_one_hot_true = lb.transform(y_true_np)
-    n_classes = y_one_hot_true.shape[1]
+    lb.fit(y_true_ww)
+    # label binarizer will output a numpy array
+    y_one_hot_true_np = lb.transform(y_true_ww)
+    n_classes = y_one_hot_true_np.shape[1]
 
     curve_data = []
     for i in range(n_classes):
         fpr_rates, tpr_rates, thresholds = sklearn_roc_curve(
-            y_one_hot_true[:, i],
-            y_pred_proba[:, i],
+            y_one_hot_true_np[:, i],
+            y_pred_proba.iloc[:, i],
         )
         auc_score = sklearn_auc(fpr_rates, tpr_rates)
         curve_data.append(
