@@ -66,6 +66,13 @@ class ARIMARegressor(Estimator):
     max_rows = 1000
     max_cols = 7
 
+    # ARIMARegressor doesn't support BooleanNullable not because of nullable type
+    # incompatibilities but because we do not handle their null values correctly
+    # https://github.com/alteryx/evalml/issues/4009
+    # IntegerNullable incompatibility: https://github.com/alteryx/evalml/issues/4015
+    # TODO: Remove when support is added https://github.com/alteryx/evalml/issues/4016
+    _integer_nullable_incompatibilities = ["X"]
+
     def __init__(
         self,
         time_index: Optional[Hashable] = None,
@@ -312,6 +319,7 @@ class ARIMARegressor(Estimator):
         X: pd.DataFrame,
         y: pd.Series = None,
         coverage: List[float] = None,
+        predictions: pd.Series = None,
     ) -> Dict[str, pd.Series]:
         """Find the prediction intervals using the fitted ARIMARegressor.
 
@@ -320,6 +328,7 @@ class ARIMARegressor(Estimator):
             y (pd.Series): Target data. Optional.
             coverage (list[float]): A list of floats between the values 0 and 1 that the upper and lower bounds of the
                 prediction interval should be calculated for.
+            predictions (pd.Series): Not used for ARIMA regressor.
 
         Returns:
             dict: Prediction intervals, keys are in the format {coverage}_lower or {coverage}_upper.
