@@ -171,6 +171,7 @@ class ProphetRegressor(Estimator):
         X: pd.DataFrame,
         y: Optional[pd.Series] = None,
         coverage: List[float] = None,
+        predictions: pd.Series = None,
     ) -> Dict[str, pd.Series]:
         """Find the prediction intervals using the fitted ProphetRegressor.
 
@@ -179,6 +180,7 @@ class ProphetRegressor(Estimator):
             y (pd.Series): Target data. Ignored.
             coverage (List[float]): A list of floats between the values 0 and 1 that the upper and lower bounds of the
                 prediction interval should be calculated for.
+            predictions (pd.Series): Not used for Prophet estimator.
 
         Returns:
             dict: Prediction intervals, keys are in the format {coverage}_lower or {coverage}_upper.
