@@ -709,7 +709,8 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         parameters_repr = ", ".join(
             [
                 f"'{component}':{{{repr_component(parameters)}}}"
-                if component != DFSTransformer.name
+                if DFSTransformer.name
+                not in component  # need to grab the component name as that is stored parameters.
                 else f"'{component}':{{}}"
                 for component, parameters in self.parameters.items()
             ],
@@ -758,10 +759,9 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             isinstance(c, (PCA, LinearDiscriminantAnalysis))
             for c in self.component_graph
         )
-        has_dfs = any(isinstance(c, DFSTransformer) for c in self.component_graph)
         # If the pipeline is a stacked ensemble, the DFS Transformer name will be different
         # and we don't need to check for the pre_existing features anyway
-        if has_dfs and not has_more_than_one_estimator:
+        if self.component_graph.has_dfs and not has_more_than_one_estimator:
             dfs_transformer = self.component_graph[DFSTransformer.name]
             input_feature_names = self.input_feature_names[DFSTransformer.name]
             contains_pre_existing_dfs_features = (
@@ -777,7 +777,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
                 has_custom_components,
                 has_dim_reduction,
                 (
-                    has_dfs
+                    self.component_graph.has_dfs
                     and not has_more_than_one_estimator
                     and not contains_pre_existing_dfs_features
                 ),
