@@ -38,6 +38,7 @@ from evalml.pipelines.components import (  # noqa: F401
     RandomForestClassifier,
     ReplaceNullableTypes,
     SelectColumns,
+    StackedEnsembleBase,
     StackedEnsembleClassifier,
     StackedEnsembleRegressor,
     StandardScaler,
@@ -641,26 +642,33 @@ def generate_pipeline_code(element, features_path=None):
             element.__class__.__name__,
         ),
     )
-    try:
-        has_dfs = element.component_graph.get_component(DFSTransformer.name)
-    except ValueError:
-        has_dfs = False
-
-    if has_dfs and not features_path:
+    if isinstance(element.estimator, StackedEnsembleBase):
+        final_estimator = element.parameters[element.estimator.name]["final_estimator"]
+        code_strings.append(
+            "from {} import {}".format(
+                final_estimator.__class__.__module__,
+                final_estimator.__class__.__name__,
+            ),
+        )
+    if element.component_graph.has_dfs and not features_path:
         warnings.warn(
             "This pipeline contains a DFS Transformer but no `features_path` has been specified. Please add a `features_path` or the pipeline code will generate a pipeline that does not run DFS.",
         )
-
-    has_dfs_and_features = has_dfs and features_path
+    has_dfs_and_features = element.component_graph.has_dfs and features_path
     if has_dfs_and_features:
         features = ft.load_features(features_path)
-        if len(features) != len(element.parameters[DFSTransformer.name]["features"]):
+        dfs_features = None
+        for component in element.parameters:
+            if "DFS Transformer" in component:
+                dfs_features = element.parameters[component]["features"]
+                break
+        if len(features) != len(dfs_features):
             raise ValueError(
                 "Provided features in `features_path` do not match pipeline features. There is a different amount of features in the loaded features.",
             )
 
         for pipeline_feature, serialized_feature in zip(
-            element.parameters[DFSTransformer.name]["features"],
+            dfs_features,
             features,
         ):
             if (
@@ -676,8 +684,10 @@ def generate_pipeline_code(element, features_path=None):
     pipeline_code = "\n".join(code_strings)
     if has_dfs_and_features:
         pipeline_code = pipeline_code.replace(
-            "'DFS Transformer':{},",
-            "'DFS Transformer':{'features':features},",
+            # this open single quote here and below is to match for
+            # DFS Transformers in pipelines with sub pipelines i.e default algo pipelines or ensemble pipelines.
+            "DFS Transformer':{},",
+            "DFS Transformer':{'features':features},",
         )
     current_dir = os.path.dirname(os.path.abspath(__file__))
     evalml_path = os.path.abspath(os.path.join(current_dir, "..", ".."))
@@ -733,13 +743,12 @@ pipeline.describe()
 df = ww.deserialize.from_disk(PATH_TO_TRAIN)
 y_train = df.ww[TARGET]
 X_train = df.ww.drop(TARGET)
-
 pipeline.fit(X_train, y_train)
 
 # You can now generate predictions as well as run model understanding.
 df = ww.deserialize.from_disk(PATH_TO_HOLDOUT)
 y_holdout = df.ww[TARGET]
-X_holdout= df.ww.drop(TARGET)
+X_holdout = df.ww.drop(TARGET)
 """
     if not is_time_series(pipeline.problem_type):
         output_str += """
