@@ -18,8 +18,6 @@ def test_polynomial_decomposer_init():
         "period": -1,
         "seasonal_smoother": 7,
         "time_index": "dates",
-        "acf_threshold": 0.01,
-        "rel_max_order": 5,
     }
 
 
@@ -42,7 +40,6 @@ def test_polynomial_decomposer_get_trend_dataframe(
     ts_data_quadratic_trend,
     ts_data_cubic_trend,
 ):
-
     if degree == 1:
         X_input, _, y_input = ts_data()
     elif degree == 2:
