@@ -181,6 +181,7 @@ def test_feature_selectors_woodwork_custom_overrides_returned_by_components(
     selector_name,
     request,
 ):
+    X_df.columns = X_df.columns.astype(str)
     selector = request.getfixturevalue(selector_name)
     y = pd.Series([1, 2, 1])
     X_df["another column"] = pd.Series([1.0, 2.0, 3.0], dtype="float")
@@ -188,7 +189,7 @@ def test_feature_selectors_woodwork_custom_overrides_returned_by_components(
     for logical_type in override_types:
         try:
             X = X_df.copy()
-            X.ww.init(logical_types={0: logical_type})
+            X.ww.init(logical_types={"0": logical_type})
         except ww.exceptions.TypeConversionError:
             continue
 
@@ -196,6 +197,6 @@ def test_feature_selectors_woodwork_custom_overrides_returned_by_components(
         transformed = selector.transform(X, y)
         assert isinstance(transformed, pd.DataFrame)
         assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
-            0: logical_type,
+            "0": logical_type,
             "another column": Double,
         }
