@@ -228,3 +228,64 @@ def test_lgbm_preserves_schema_in_rename(mock_predict, mock_fit):
     assert mock_fit.call_args[0][0].ww.schema == original_schema
     lgb.predict(X)
     assert mock_predict.call_args[0][0].ww.schema == original_schema
+
+
+@pytest.mark.parametrize(
+    "nullable_y_ltype",
+    ["IntegerNullable", "AgeNullable", "BooleanNullable"],
+)
+def test_lgbm_handle_nullable_types(
+    nullable_type_test_data,
+    nullable_type_target,
+    nullable_y_ltype,
+):
+    y = nullable_type_target(ltype=nullable_y_ltype, has_nans=False)
+    X = nullable_type_test_data(has_nans=False)
+    X = X.ww.select(include=["numeric", "Boolean", "BooleanNullable"])
+
+    lgb = LightGBMRegressor()
+
+    X, y = lgb._handle_nullable_types(X, y)
+    lgb.fit(X, y)
+    preds = lgb.predict(X)
+
+    assert not preds.isnull().any().any()
+
+
+@pytest.mark.parametrize(
+    "nullable_y_ltype",
+    ["IntegerNullable", "AgeNullable", "BooleanNullable"],
+)
+@pytest.mark.parametrize(
+    "handle_incompatibility",
+    [
+        True,
+        pytest.param(
+            False,
+            marks=pytest.mark.xfail(strict=True, raises=ValueError),
+        ),
+    ],
+)
+def test_lgbm_regressor_nullable_type_incompatibility(
+    nullable_type_target,
+    nullable_type_test_data,
+    lgbm,
+    handle_incompatibility,
+    nullable_y_ltype,
+):
+    """Testing that the nullable type incompatibility that caused us to add handling for LightGBMRegressor
+    is still present in sklearn's LGBMRegressor component. If this test is causing the test suite to fail
+    because the code below no longer raises the expected ValueError, we should confirm that the nullable
+    types now work for our use case and remove the nullable type handling logic from LightGBMRegressor.
+    """
+    y = nullable_type_target(ltype=nullable_y_ltype, has_nans=False)
+    X = nullable_type_test_data(has_nans=False)
+    X = X.ww.select(include=["numeric", "Boolean", "BooleanNullable"])
+
+    if handle_incompatibility:
+        lgb = LightGBMRegressor()
+        X, y = lgb._handle_nullable_types(X, y)
+
+    sk_lgb = lgbm.sklearn.LGBMRegressor()
+    sk_lgb.fit(X, y)
+    sk_lgb.predict(X)
