@@ -1,13 +1,16 @@
 import os
 from unittest.mock import patch
 
+import black
 import pytest
 from click.testing import CliRunner
 from packaging.requirements import Requirement
 
 from evalml.__main__ import cli
 from evalml.utils.cli_utils import (
+    get_evalml_black_config,
     get_evalml_pip_requirements,
+    get_evalml_requirements_file,
     get_evalml_root,
     get_installed_packages,
     get_sys_info,
@@ -73,6 +76,24 @@ def test_print_deps_info(caplog, current_dir):
         assert requirement in out
 
 
+def test_get_deps_file(current_dir, tmpdir):
+    evalml_path = os.path.abspath(os.path.join(current_dir, "..", "..", ".."))
+    path = os.path.join(str(tmpdir), "requirements.txt")
+    assert not os.path.exists(path)
+
+    requirements_return = get_evalml_requirements_file(evalml_path, path)
+    assert os.path.exists(path)
+
+    requirement_file = open(path, "r")
+    requirement_file = requirement_file.read()
+
+    requirements = get_requirements(current_dir)
+    for requirement in requirements:
+        assert requirement in requirement_file
+
+    assert requirement_file == requirements_return
+
+
 def test_sys_info():
     sys_info = get_sys_info()
     info_keys = [
@@ -107,3 +128,16 @@ def test_installed_packages(current_dir):
 def test_get_evalml_root(current_dir):
     root = os.path.abspath(os.path.join(current_dir, "..", ".."))
     assert get_evalml_root() == root
+
+
+def test_get_evalml_black_config(current_dir):
+    evalml_path = os.path.abspath(os.path.join(current_dir, "..", "..", ".."))
+    black_config = get_evalml_black_config(evalml_path)
+    assert black_config["line_length"] == 88
+    assert black_config["target_versions"] == set([black.TargetVersion["PY39"]])
+
+    black_config = get_evalml_black_config(
+        os.path.join(current_dir, "..", "..", "random_file"),
+    )
+    assert black_config["line_length"] == 88
+    assert black_config["target_versions"] == set([black.TargetVersion["PY39"]])
