@@ -6,6 +6,7 @@ import platform
 import struct
 import sys
 
+import black
 import pkg_resources
 import tomli
 from packaging.requirements import Requirement
@@ -158,3 +159,54 @@ def get_evalml_pip_requirements(
         convert_to_conda=convert_to_conda,
     )
     return standardized_package_specifiers
+
+
+def get_evalml_requirements_file(evalml_path, requirements_file_path):
+    """Gets pip requirements for evalml as a requirements file
+
+    Args:
+        evalml_path: Path to evalml root.
+        requirements_file_path: Path to requirements file.
+    Returns:
+        Pip requirements for evalml in a singular string.
+    """
+    requirements = "\n".join(
+        get_evalml_pip_requirements(evalml_path, convert_to_conda=False),
+    )
+    with open(requirements_file_path, "w") as text_file:
+        text_file.write(requirements)
+    return requirements
+
+
+def get_evalml_black_config(
+    evalml_path,
+):
+    """Gets configuration for black.
+
+    Args:
+        evalml_path: Path to evalml root.
+
+    Returns:
+        Dictionary of black configuration.
+    """
+    black_config = None
+    try:
+        toml_dict = None
+        evalml_path = pathlib.Path(evalml_path, "pyproject.toml")
+        with open(evalml_path, "rb") as f:
+            toml_dict = tomli.load(f)
+        black_config = toml_dict["tool"]["black"]
+        black_config["line_length"] = black_config.pop("line-length")
+        target_versions = set(
+            [
+                black.TargetVersion[ver.upper()]
+                for ver in black_config.pop("target-version")
+            ],
+        )
+        black_config["target_versions"] = target_versions
+    except Exception:
+        black_config = {
+            "line_length": 88,
+            "target_versions": set([black.TargetVersion["PY39"]]),
+        }
+    return black_config
